@@ -24,6 +24,10 @@ pub enum EducationalLevel {
     BACHELOR,
     #[serde(rename = "MASTER")]
     MASTER,
+    #[serde(rename = "DOCTOR")]
+    DOCTOR,
+    #[serde(rename = "OTHER")]
+    OTHER,
 }
 
 impl std::fmt::Display for EducationalLevel {
@@ -34,6 +38,8 @@ impl std::fmt::Display for EducationalLevel {
             EducationalLevel::HIGH_SCHOOL => write!(f, "{}", "HIGH_SCHOOL"),
             EducationalLevel::BACHELOR => write!(f, "{}", "BACHELOR"),
             EducationalLevel::MASTER => write!(f, "{}", "MASTER"),
+            EducationalLevel::DOCTOR => write!(f, "{}", "DOCTOR"),
+            EducationalLevel::OTHER => write!(f, "{}", "OTHER"),
         }
     }
 }
@@ -48,6 +54,8 @@ impl std::str::FromStr for EducationalLevel {
             "HIGH_SCHOOL" => std::result::Result::Ok(EducationalLevel::HIGH_SCHOOL),
             "BACHELOR" => std::result::Result::Ok(EducationalLevel::BACHELOR),
             "MASTER" => std::result::Result::Ok(EducationalLevel::MASTER),
+            "DOCTOR" => std::result::Result::Ok(EducationalLevel::DOCTOR),
+            "OTHER" => std::result::Result::Ok(EducationalLevel::OTHER),
             _ => std::result::Result::Err(format!("Value not valid: {}", s)),
         }
     }
@@ -573,10 +581,6 @@ pub struct StudentUpsert {
     #[serde(skip_serializing_if="Option::is_none")]
     pub race: Option<String>,
 
-    #[serde(rename = "programId")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub program_id: Option<uuid::Uuid>,
-
     #[serde(rename = "idNumber")]
     #[serde(skip_serializing_if="Option::is_none")]
     pub id_number: Option<String>,
@@ -585,10 +589,6 @@ pub struct StudentUpsert {
     #[serde(skip_serializing_if="Option::is_none")]
     pub id_number_provider: Option<models::IdNumberProvider>,
 
-    #[serde(rename = "passport")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub passport: Option<String>,
-
     #[serde(rename = "dateOfIssue")]
     #[serde(skip_serializing_if="Option::is_none")]
     pub date_of_issue: Option<NaiveDate>,
@@ -618,10 +618,8 @@ impl StudentUpsert {
             educational_stage: None,
             foreign_language: None,
             race: None,
-            program_id: None,
             id_number: None,
             id_number_provider: None,
-            passport: None,
             date_of_issue: None,
             place_of_issue: None,
         }
@@ -702,8 +700,6 @@ impl std::string::ToString for StudentUpsert {
             params.push(race.to_string());
         }
 
-        // Skipping programId in query parameter serialization
-
 
         if let Some(ref id_number) = self.id_number {
             params.push("idNumber".to_string());
@@ -712,12 +708,6 @@ impl std::string::ToString for StudentUpsert {
 
         // Skipping idNumberProvider in query parameter serialization
 
-
-        if let Some(ref passport) = self.passport {
-            params.push("passport".to_string());
-            params.push(passport.to_string());
-        }
-
         // Skipping dateOfIssue in query parameter serialization
 
 
@@ -756,10 +746,8 @@ impl std::str::FromStr for StudentUpsert {
             pub educational_stage: Vec<Vec<models::EducationalStage>>,
             pub foreign_language: Vec<Vec<models::ForeignLanguage>>,
             pub race: Vec<String>,
-            pub program_id: Vec<uuid::Uuid>,
             pub id_number: Vec<String>,
             pub id_number_provider: Vec<models::IdNumberProvider>,
-            pub passport: Vec<String>,
             pub date_of_issue: Vec<NaiveDate>,
             pub place_of_issue: Vec<String>,
         }
@@ -794,10 +782,8 @@ impl std::str::FromStr for StudentUpsert {
                     "educationalStage" => return std::result::Result::Err("Parsing a container in this style is not supported in StudentUpsert".to_string()),
                     "foreignLanguage" => return std::result::Result::Err("Parsing a container in this style is not supported in StudentUpsert".to_string()),
                     "race" => intermediate_rep.race.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "programId" => intermediate_rep.program_id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "idNumber" => intermediate_rep.id_number.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "idNumberProvider" => intermediate_rep.id_number_provider.push(<models::IdNumberProvider as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "passport" => intermediate_rep.passport.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "dateOfIssue" => intermediate_rep.date_of_issue.push(<NaiveDate as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "placeOfIssue" => intermediate_rep.place_of_issue.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing StudentUpsert".to_string())
@@ -826,10 +812,8 @@ impl std::str::FromStr for StudentUpsert {
             educational_stage: intermediate_rep.educational_stage.into_iter().next(),
             foreign_language: intermediate_rep.foreign_language.into_iter().next(),
             race: intermediate_rep.race.into_iter().next(),
-            program_id: intermediate_rep.program_id.into_iter().next(),
             id_number: intermediate_rep.id_number.into_iter().next(),
             id_number_provider: intermediate_rep.id_number_provider.into_iter().next(),
-            passport: intermediate_rep.passport.into_iter().next(),
             date_of_issue: intermediate_rep.date_of_issue.into_iter().next(),
             place_of_issue: intermediate_rep.place_of_issue.into_iter().next(),
         })
